shill: Reset Config80211 state at the end of ShillDaemonTest::Quit.

This prevents later tests from using corrupted memory.

BUG=chromium-os:38279
TEST=unit tests

Change-Id: Ie93e41273bc241d9f4c81a6ea291c7525a05bd84
Reviewed-on: https://gerrit.chromium.org/gerrit/42113
Tested-by: Darin Petkov <petkov@chromium.org>
Commit-Queue: Darin Petkov <petkov@chromium.org>
Reviewed-by: Darin Petkov <petkov@chromium.org>
diff --git a/config80211.h b/config80211.h
index 54e2d25..8801521 100644
--- a/config80211.h
+++ b/config80211.h
@@ -137,6 +137,7 @@
 
  private:
   friend class Config80211Test;
+  friend class ShillDaemonTest;
   FRIEND_TEST(Config80211Test, BroadcastCallbackTest);
   FRIEND_TEST(Config80211Test, MessageCallbackTest);
   typedef std::map<EventType, std::string> EventTypeStrings;
@@ -161,9 +162,9 @@
   // Called by InputHandler on exceptional events.
   void OnReadError(const Error &error);
 
-  // Just for tests, this method turns off WiFi and clears the subscribed
-  // events list.
-  void Reset();
+  // Just for tests, this method turns off WiFi and clears the subscribed events
+  // list. If |full| is true, also clears state set by Init.
+  void Reset(bool full);
 
   // Config80211 Callbacks, OnRawNlMessageReceived invokes each of these
   // User-supplied callback object when _it_ gets called to read libnl data.